@@ -16,12 +16,13 @@ module DBF
       #
       #  # Calling a table
       #  contacts = db.contacts.record(0)
+      #
+      # @param path [String]
       def initialize(path)
         @path = path
         @dirname = File.dirname(@path)
         @db = DBF::Table.new(@path)
         @tables = extract_dbc_data
-
       rescue Errno::ENOENT
         raise DBF::FileNotFoundError, "file not found: #{data}"
       end
@@ -31,9 +32,11 @@ module DBF
       end
 
       # Returns table with given name
-      # @return Table
+      #
+      # @param name [String]
+      # @return [DBF::Table]
       def table(name)
-        Table.new(table_path name) do |table|
+        Table.new table_path(name) do |table|
           table.long_names = @tables[name]
         end
       end
@@ -41,25 +44,23 @@ module DBF
       # Searches the database directory for the table's dbf file
       # and returns the absolute path. Ensures case-insensitivity
       # on any platform.
-      # @return String
+      # @param name [String]
+      # @return [String]
       def table_path(name)
-        example = File.join(@dirname, "#{name}.dbf")
-        glob = File.join(@dirname, '*')
-        path = Dir.glob(glob).find { |match| match.downcase == example.downcase }
+        glob = File.join(@dirname, "#{name}.dbf")
+        path = Dir.glob(glob, File::FNM_CASEFOLD).first
 
-        unless path && File.exist?(path)
-          raise DBF::FileNotFoundError, "related table not found: #{name}"
-        end
+        raise DBF::FileNotFoundError, "related table not found: #{name}" unless path && File.exist?(path)
 
         path
       end
 
-      def method_missing(method, *args) # nodoc
-        if table_names.index(method.to_s)
-          table method.to_s
-        else
-          super
-        end
+      def method_missing(method, *args) # :nodoc:
+        table_names.index(method.to_s) ? table(method.to_s) : super
+      end
+
+      def respond_to_missing?(method, *)
+        table_names.index(method.to_s) || super
       end
 
       private
@@ -68,7 +69,7 @@ module DBF
       # just an ordinary table with a treelike structure. Field definitions
       # are in the same order as in the linked tables but only the long name
       # is provided.
-      def extract_dbc_data # nodoc
+      def extract_dbc_data # :nodoc:
         data = {}
         @db.each do |record|
           next unless record
@@ -111,7 +112,7 @@ module DBF
     class Table < DBF::Table
       attr_accessor :long_names
 
-      def build_columns # nodoc
+      def build_columns # :nodoc:
         columns = super
 
         # modify the column definitions to use the long names as the
