@@ -3,7 +3,7 @@ module DBF
     class Foxpro < Base
       FPT_HEADER_SIZE = 512
 
-      def build_memo(start_block) # nodoc
+      def build_memo(start_block) # :nodoc:
         @data.seek offset(start_block)
 
         memo_type, memo_size, memo_string = @data.read(block_size).unpack('NNa*')
@@ -15,17 +15,16 @@ module DBF
           memo_string = memo_string[0, memo_size]
         end
         memo_string
-
-      rescue
+      rescue StandardError
         nil
       end
 
       private
 
-      def block_size # nodoc
+      def block_size # :nodoc:
         @block_size ||= begin
           @data.rewind
-          @data.read(FPT_HEADER_SIZE).unpack('x6n').first || 0
+          @data.read(FPT_HEADER_SIZE).unpack1('x6n') || 0
         end
       end
     end
